Crate pest3

Crate pest3 

Core part of pest3.

Modules

choice
error
Types for different kinds of parsing failures.
formatter
position
sequence
span
std
Re-exported items from std.
token
typed

Structs

Position
A cursor position in a &str which provides useful methods to manually parse that string.
Span
A span over a &str. It is created from either two Positions or from a Pair.
Stack
Implementation of a Stack which maintains popped elements and length of previous states in order to rewind the stack to a previous state.

Traits

RuleType
A trait which parser rules must implement.